************
User's guide
************

This is the AiiDA-FLEUR user's guide.

.. toctree::
   :maxdepth: 4

   ./getting_started/getting_started
   ./data/fleur_data_plugins
   ./calculations/fleur_calculation_plugins
   ./workflows/wc_index
   ./cmd/cmd_index
   ./tools/tools_index
   ./tutorials/tutorials
   ./hints/hints_faq
   ./hints/exit_codes
